@@ -4,7 +4,7 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: addr.c,v 6.4 1993/06/06 00:06:13 panos Exp $" ;
+static char RCSid[] = "$Id: addr.c,v 1.1 1996/01/24 19:29:19 chuck Exp $" ;
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -250,7 +250,7 @@ PRIVATE result_e numeric_addr( str_addr, op, addr_list )
 	register unsigned long mask ;
 	struct comp_addr ca ;
 
-	addr = inet_addr( str_addr ) ;
+	addr = ntohl( inet_addr( str_addr ) ) ;
 	if ( addr == (unsigned long) -1 )
 		return( CANT_PARSE ) ;
 
