@@ -4,7 +4,7 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: builtins.c,v 6.9 1993/06/15 23:25:57 panos Exp $" ;
+static char RCSid[] = "$Id: builtins.c,v 1.5 1995/09/10 18:41:13 chuck Exp $" ;
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -126,8 +126,8 @@ PRIVATE void dgram_echo( serp )
 {
 	char						buf[ DATAGRAM_SIZE ] ;
 	struct sockaddr_in	sin ;
-	int						sin_len ;
 	int						cc ;
+	int						sin_len = sizeof( sin ) ;
 	int						descriptor = SERVER_FD( serp ) ;
 
 	cc = recvfrom( descriptor, buf, sizeof( buf ), 0, SA( &sin ), &sin_len ) ;
@@ -182,12 +182,24 @@ PRIVATE void daytime_protocol( buf, buflen )
 	struct tm	*tmp ;
 	int			size = *buflen ;
 	
+#ifdef linux
+	char tzname[2];
+
+	(void) time( &now ) ;
+	tmp = localtime( &now ) ;
+	mktime(tmp);
+        strx_print( buflen, buf, size,
+                "%02d %s %d %02d:%02d:%02d %c%cT\r\n",
+                tmp->tm_mday, month_name[ tmp->tm_mon ], 1900 + tmp->tm_year,
+                tmp->tm_hour, tmp->tm_min, tmp->tm_sec, tzname[0], tzname[1] ) ;
+#else
 	(void) time( &now ) ;
 	tmp = localtime( &now ) ;
 	strx_print( buflen, buf, size,
 		"%02d %s %d %02d:%02d:%02d %s\r\n",
-			tmp->tm_mday, month_name[ tmp->tm_mon ], 1900 + tmp->tm_year,
-				tmp->tm_hour, tmp->tm_min, tmp->tm_sec, tmp->tm_zone ) ;
+		tmp->tm_mday, month_name[ tmp->tm_mon ], 1900 + tmp->tm_year,
+		tmp->tm_hour, tmp->tm_min, tmp->tm_sec, tmp->tm_zone ) ;
+#endif	/* linux */
 }
 
 
@@ -220,8 +232,11 @@ PRIVATE void dgram_daytime( serp )
 	(void) sendto( descriptor, time_buf, buflen, 0, SA(&sin), sizeof( sin ) ) ;
 }
 
-
+#if defined(linux) || defined(__FreeBSD__) || defined(__bsdi__) || defined(__NetBSD__)
+#define TIME_OFFSET			2208988800UL
+#else
 #define TIME_OFFSET			2208988800
+#endif
 
 /*
  * We always report the time using network-byte-order
