@@ -4,10 +4,12 @@
  * and conditions for redistribution.
  */
 
-static char RCSid[] = "$Id: conf.c,v 6.4 1993/06/01 22:59:39 panos Exp $" ;
+static char RCSid[] = "$Id: conf.c,v 1.3 1995/09/10 18:41:13 chuck Exp $" ;
 
 #include <sys/types.h>
+#if defined(BSD) || defined(linux)
 #include <netinet/in.h>
+#endif
 #include <syslog.h>
 #include <fcntl.h>
 #include <string.h>
