@@ -5,12 +5,21 @@
  */
 
 #include <sys/types.h>
+#include <sys/param.h>
 #include <syslog.h>
 #include <netdb.h>
 #include <string.h>
-#include <netinet/in.h>
 
+#if defined(BSD) || defined(linux)
+#include <netinet/in.h>
+#endif
+
+#if defined(BSD)
+#include <rpc/rpc.h>
+#else
 char *malloc() ;
+#endif
+
 void endservent() ;
 void endprotoent() ;
 void endrpcent() ;
@@ -213,7 +222,10 @@ PRIVATE status_e attr_check( scp )
 
 	if ( SC_IS_RPC( scp ) )
 		if ( SC_IS_UNLISTED( scp ) )
+		{
 			M_OR( must_specify, must_specify, NECESSARY_ATTRS_RPC_UNLISTED ) ;
+			M_CLEAR( must_specify, A_PORT ) ;
+		}
 		else
 			M_OR( must_specify, must_specify, NECESSARY_ATTRS_RPC_LISTED ) ;
 
@@ -221,7 +233,8 @@ PRIVATE status_e attr_check( scp )
 	 * Check if all necessary attributes have been specified
 	 *
 	 * NOTE: None of the necessary attributes can belong to "defaults"
-	 *			This is why we use the sc_attributes_specified mask.
+	 *			This is why we use the sc_attributes_specified mask instead
+	 *			of the sc_attributes_present mask.
 	 */
 	M_AND( necessary_and_specified,
 						scp->sc_specified_attributes, must_specify ) ;
