@@ -8,11 +8,13 @@
 #define INT_H
 
 /*
- * $Id: int.h,v 6.5 1993/06/06 00:06:43 panos Exp $
+ * $Id: int.h,v 1.2 1995/09/10 15:42:38 chuck Exp $
  */
 
 #include <sys/types.h>
+#ifdef BSD
 #include <netinet/in.h>
+#endif
 
 #include "pset.h"
 
