@@ -25,12 +25,6 @@ static char RCSid[] = "$Id" ;
 #include "addr.h"
 
 char *malloc() ;
-void endprotoent() ;
-void endpwent() ;
-void endgrent() ;
-int endnetent() ;
-void endhostent() ;
-
 
 void parsemsg() ;
 void msg() ;
@@ -68,6 +62,9 @@ status_e flags_parser() ;
 status_e disabled_parser() ;
 status_e rpc_number_parser() ;
 status_e nice_parser() ;
+#ifdef BIND_IF
+status_e interface_parser(); /* NV */
+#endif
 
 /*
  * A NULL value for the name field marks the end of the table
@@ -80,32 +77,35 @@ status_e nice_parser() ;
  */
 static struct attribute service_attributes[] =
 	{
-		{ "socket_type", 		A_SOCKET_TYPE,		1,		socket_type_parser 		},
-		{ "protocol",			A_PROTOCOL,			1,		protocol_parser 			},
-		{ "wait",				A_WAIT,				1,		wait_parser					},
-		{ "user", 				A_USER, 				1,		user_parser					},
-		{ "group", 				A_GROUP,				1,		group_parser 				},
-		{ "server",				A_SERVER,			1,		server_parser				},
-		{ "server_args",		A_SERVER_ARGS,		-1,	server_args_parser		},
-		{ "instances",			A_INSTANCES,		1,		instances_parser			},
+		{ "socket_type", 		A_SOCKET_TYPE,	 1,	socket_type_parser 		},
+		{ "protocol",			A_PROTOCOL,		 1,	protocol_parser			},
+		{ "wait",				A_WAIT,			 1,	wait_parser				},
+		{ "user", 				A_USER, 		 1,	user_parser				},
+		{ "group", 				A_GROUP,		 1,	group_parser 			},
+		{ "server",				A_SERVER,		 1,	server_parser			},
+		{ "server_args",		A_SERVER_ARGS,	-1,	server_args_parser		},
+		{ "instances",			A_INSTANCES,	 1,	instances_parser		},
 		{ "log_on_success",	A_LOG_ON_SUCCESS,	-2,	log_on_success_parser	},
 		{ "log_on_failure",	A_LOG_ON_FAILURE,	-2,	log_on_failure_parser	},
-		{ "log_type",			A_LOG_TYPE,			-1,	log_type_parser			},
-		{ "only_from",			A_ONLY_FROM,		-2,	only_from_parser			},
-		{ "no_access",			A_NO_ACCESS,		-2,	no_access_parser			},
-		{ "access_times",		A_ACCESS_TIMES,	-1,	access_times_parser		},
-		{ "type",				A_TYPE,				-1,	type_parser					},
+		{ "log_type",			A_LOG_TYPE,		-1,	log_type_parser			},
+		{ "only_from",			A_ONLY_FROM,	-2,	only_from_parser	},
+		{ "no_access",			A_NO_ACCESS,	-2,	no_access_parser	},
+		{ "access_times",		A_ACCESS_TIMES,	-1,	access_times_parser	},
+		{ "type",				A_TYPE,			-1,	type_parser			},
 #ifndef NO_RPC
-		{ "rpc_version",		A_RPC_VERSION,		1,		rpc_version_parser		},
-		{ "rpc_number",		A_RPC_NUMBER,		1,		rpc_number_parser			},
+		{ "rpc_version",		A_RPC_VERSION,	 1,	rpc_version_parser	},
+		{ "rpc_number",			A_RPC_NUMBER,	 1,	rpc_number_parser	},
 #endif
-		{ "id",					A_ID,					1,		id_parser					},
-		{ "env",					A_ENV,				-2,	env_parser					},
-		{ "port",				A_PORT,				1,		port_parser					},
-		{ "passenv",			A_PASSENV,			-2,	passenv_parser				},
-		{ "flags",				A_FLAGS,				-1,	flags_parser				},
-		{ "nice",				A_NICE,				1,		nice_parser					},
-		{ NULL,					A_NONE,				-1,	NULL							}
+		{ "id",					A_ID,			 1,	id_parser			},
+		{ "env",					A_ENV,		-2,	env_parser			},
+		{ "port",				A_PORT,			 1,	port_parser			},
+		{ "passenv",			A_PASSENV,		-2,	passenv_parser		},
+		{ "flags",				A_FLAGS,		-1,	flags_parser		},
+		{ "nice",				A_NICE,			 1,	nice_parser			},
+#ifdef BIND_IF
+		{ "interface",			A_INTERFACE,	 1,	interface_parser	},
+#endif
+		{ NULL,					A_NONE,			-1,	NULL				}
 	} ;
 
 static struct attribute default_attributes[] =
@@ -116,9 +116,12 @@ static struct attribute default_attributes[] =
       { "disabled",        A_DISABLED,       -2,   disabled_parser       },
       { "no_access",       A_NO_ACCESS,      -2,   no_access_parser      },
       { "only_from",       A_ONLY_FROM,      -2,   only_from_parser      },
-      { "instances",       A_INSTANCES,      1,    instances_parser      },
+      { "instances",       A_INSTANCES,       1,   instances_parser      },
       { "passenv",         A_PASSENV,        -2,   passenv_parser        },
-      { NULL,              A_NONE,           0,    NULL                      }
+#ifdef BIND_IF
+      { "interface",       A_INTERFACE,       1,   interface_parser      },
+#endif
+      { NULL,              A_NONE,            0,   NULL                  }
    } ;
 
 
@@ -437,6 +440,12 @@ PRIVATE void fill_attribute( attr_id, scp, def )
 									&scp->sc_pass_env_vars, 0 ) == OK )
 				SC_PRESENT( scp, A_PASSENV ) ;
 			break ;
+#ifdef BIND_IF
+		case A_INTERFACE:
+			def->sc_interface.s_addr =  scp->sc_interface.s_addr ;
+			SC_PRESENT( scp, A_INTERFACE ) ;
+			break ;
+#endif
 	}
 }
 
@@ -471,16 +480,17 @@ PRIVATE struct attribute *attr_lookup( attr_array, attr_name )
  * Invoke appropriate parser
  */
 PRIVATE void identify_attribute( entry_type, scp, defaults,
-														attr_name, op, attr_values )
-	entry_e						entry_type ;
+								 attr_name, op, attr_values )
+	entry_e					entry_type ;
 	struct service_config	*scp ;
 	struct service_config	*defaults ;
-	register char				*attr_name ;
-	enum assign_op				op ;
-	pset_h						attr_values ;
+	register char			*attr_name ;
+	enum assign_op			op ;
+	pset_h					attr_values ;
 {
 	register struct attribute	*ap ;
-	char								*func = "identify_attribute" ;
+	char						*func = "identify_attribute" ;
+
 
 	if ( entry_type == SERVICE_ENTRY )
 		ap = attr_lookup( service_attributes, attr_name ) ;
@@ -492,6 +502,7 @@ PRIVATE void identify_attribute( entry_type, scp, defaults,
 
 	if ( ! MODIFIABLE( ap ) )
 	{
+
 		if ( SC_SPECIFIED( scp, ap->a_id ) )
 		{
 			parsemsg( LOG_WARNING, func, "Service %s: attribute already set: %s",
@@ -532,8 +543,10 @@ PRIVATE void identify_attribute( entry_type, scp, defaults,
 		return ;
 	}
 
+
 	if ( (*ap->a_parser)( attr_values, scp, op ) == OK )
 		SC_SPECIFY( scp, ap->a_id ) ;
+
 }
 
 
